@@ -4,6 +4,8 @@ from .arquivos import Arquivos  # noqa
 from .caso import Caso  # noqa
 from .dadger import Dadger  # noqa
 from .dadgnl import DadGNL  # noqa
+from .decomptim import DecompTim  # noqa
+from .fcfnw import Fcfnw  # noqa
 from .hidr import Hidr  # noqa
 from .inviabunic import InviabUnic  # noqa
 from .postos import Postos  # noqa
